import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CapturePolicyListModel } from '../model/capturePolicyListModel';
import { CapturePolicyModel } from '../model/capturePolicyModel';
import { Operation } from '../model/operation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsCapturePoliciesByIdGet {
    interface Params {
        /**
        * The ID of the capture policy.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCapturePoliciesByIdPatch {
    interface Params {
        /**
        * The id of the capture policy to be modified.
        */
        id: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCapturePoliciesGet {
    interface Params {
        /**
        * Filter capture policies by the specified property
        */
        propertyId?: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
        */
        pageNumber?: number;
        /**
        * Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
        */
        pageSize?: number;
    }
}
export declare class CapturePoliciesService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get a specific capture policy.
     * Get a specific capture policy.&lt;br&gt;You must have at least one of these scopes: &#39;settings.read, setup.read, setup.manage&#39;.
     * @param $params.id The ID of the capture policy.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCapturePoliciesByIdGet($params: settingsCapturePoliciesByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CapturePolicyModel>;
    settingsCapturePoliciesByIdGet($params: settingsCapturePoliciesByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CapturePolicyModel>>;
    settingsCapturePoliciesByIdGet($params: settingsCapturePoliciesByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CapturePolicyModel>>;
    /**
     * Allows to modify properties of a capture policy.
     * Here is the list of operations that are currently allowed:  - Replace captureNoShowFee flag  - Replace captureCancellationFee flag  - Replace capturePrepayment flag  - Replace PostOtaBankTransferOnCheckOut flag  - Replace capturePayment configuration&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.id The id of the capture policy to be modified.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCapturePoliciesByIdPatch($params: settingsCapturePoliciesByIdPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsCapturePoliciesByIdPatch($params: settingsCapturePoliciesByIdPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsCapturePoliciesByIdPatch($params: settingsCapturePoliciesByIdPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get all capture policies.
     * Get the list of capture policies.&lt;br&gt;You must have at least one of these scopes: &#39;settings.read, setup.read, setup.manage&#39;.
     * @param $params.propertyId Filter capture policies by the specified property
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.pageNumber Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCapturePoliciesGet($params: settingsCapturePoliciesGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CapturePolicyListModel | null>;
    settingsCapturePoliciesGet($params: settingsCapturePoliciesGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CapturePolicyListModel | null>>;
    settingsCapturePoliciesGet($params: settingsCapturePoliciesGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CapturePolicyListModel | null>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CapturePoliciesService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CapturePoliciesService>;
}
