import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CityTaxCreatedModel } from '../model/cityTaxCreatedModel';
import { CityTaxListModel } from '../model/cityTaxListModel';
import { CityTaxModel } from '../model/cityTaxModel';
import { CreateCityTaxModel } from '../model/createCityTaxModel';
import { Operation } from '../model/operation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsCityTaxByIdDelete {
    interface Params {
        /**
        * The ID of the city tax to remove.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCityTaxByIdGet {
    interface Params {
        /**
        * The ID of the city tax.
        */
        id: string;
        /**
        * 'all' or comma separated list of two-letter language codes (ISO Alpha-2)
        */
        languages?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCityTaxByIdPatch {
    interface Params {
        /**
        * The id of the city tax to be modified.
        */
        id: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCityTaxGet {
    interface Params {
        /**
        * Filter by the specified property
        */
        propertyId?: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCityTaxPost {
    interface Params {
        /**
        * The definition of the city tax.
        */
        body: CreateCityTaxModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare class CityTaxService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Delete a city tax
     * Use this call to delete a city tax.&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.id The ID of the city tax to remove.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCityTaxByIdDelete($params: settingsCityTaxByIdDelete.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsCityTaxByIdDelete($params: settingsCityTaxByIdDelete.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsCityTaxByIdDelete($params: settingsCityTaxByIdDelete.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get a specific city tax.
     * Get a specific city tax.&lt;br&gt;You must have at least one of these scopes: &#39;settings.read, setup.read, setup.manage&#39;.
     * @param $params.id The ID of the city tax.
     * @param $params.languages &#39;all&#39; or comma separated list of two-letter language codes (ISO Alpha-2)
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCityTaxByIdGet($params: settingsCityTaxByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CityTaxModel>;
    settingsCityTaxByIdGet($params: settingsCityTaxByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CityTaxModel>>;
    settingsCityTaxByIdGet($params: settingsCityTaxByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CityTaxModel>>;
    /**
     * Allows to modify city tax
     * Here is the list of operations that are currently allowed:  - Replace name and description  - Replace value and type  - Replace or delete the VAT type  - Replace priority&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.id The id of the city tax to be modified.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCityTaxByIdPatch($params: settingsCityTaxByIdPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsCityTaxByIdPatch($params: settingsCityTaxByIdPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsCityTaxByIdPatch($params: settingsCityTaxByIdPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get all city taxes.
     * Get the list of all city taxes.&lt;br&gt;You must have at least one of these scopes: &#39;settings.read, setup.read, setup.manage&#39;.
     * @param $params.propertyId Filter by the specified property
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCityTaxGet($params: settingsCityTaxGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CityTaxListModel | null>;
    settingsCityTaxGet($params: settingsCityTaxGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CityTaxListModel | null>>;
    settingsCityTaxGet($params: settingsCityTaxGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CityTaxListModel | null>>;
    /**
     * Create a city tax.
     * You can only create one city tax per property. It can be changed and deleted any time.&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.body The definition of the city tax.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCityTaxPost($params: settingsCityTaxPost.Params, observe?: 'body', reportProgress?: boolean): Observable<CityTaxCreatedModel>;
    settingsCityTaxPost($params: settingsCityTaxPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CityTaxCreatedModel>>;
    settingsCityTaxPost($params: settingsCityTaxPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CityTaxCreatedModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CityTaxService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CityTaxService>;
}
