import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CreateCustomFeeModel } from '../model/createCustomFeeModel';
import { CustomFeeCreatedModel } from '../model/customFeeCreatedModel';
import { CustomFeeListModel } from '../model/customFeeListModel';
import { CustomFeeModel } from '../model/customFeeModel';
import { Operation } from '../model/operation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsCustomFeesByIdDelete {
    interface Params {
        /**
        * The id of the fee.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCustomFeesByIdGet {
    interface Params {
        /**
        * The id of the fee.
        */
        id: string;
        /**
        * 'all' or comma separated list of two-letter language codes (ISO Alpha-2)
        */
        languages?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCustomFeesByIdPatch {
    interface Params {
        /**
        * The id of the fee to be modified.
        */
        id: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCustomFeesGet {
    interface Params {
        /**
        * Filter fees by the specified property
        */
        propertyId?: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsCustomFeesPost {
    interface Params {
        /**
        * The definition of the fee.
        */
        body: CreateCustomFeeModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare class CustomFeeService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Delete a fee.
     * Use this call to delete a fee.&lt;br&gt;You must have at least one of these scopes: &#39;fees.delete, setup.manage&#39;.
     * @param $params.id The id of the fee.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCustomFeesByIdDelete($params: settingsCustomFeesByIdDelete.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsCustomFeesByIdDelete($params: settingsCustomFeesByIdDelete.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsCustomFeesByIdDelete($params: settingsCustomFeesByIdDelete.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get a specific fee.
     * Get a specific fee.&lt;br&gt;You must have at least one of these scopes: &#39;fees.read, setup.read, setup.manage&#39;.
     * @param $params.id The id of the fee.
     * @param $params.languages &#39;all&#39; or comma separated list of two-letter language codes (ISO Alpha-2)
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCustomFeesByIdGet($params: settingsCustomFeesByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CustomFeeModel>;
    settingsCustomFeesByIdGet($params: settingsCustomFeesByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CustomFeeModel>>;
    settingsCustomFeesByIdGet($params: settingsCustomFeesByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CustomFeeModel>>;
    /**
     * Allows to modify properties of a fee.
     * Here is the list of operations that are currently allowed:  - Replace name  - Replace percentValue  - Add, replace and remove subAccountId&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.id The id of the fee to be modified.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCustomFeesByIdPatch($params: settingsCustomFeesByIdPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsCustomFeesByIdPatch($params: settingsCustomFeesByIdPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsCustomFeesByIdPatch($params: settingsCustomFeesByIdPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get all fees.
     * Get the list of fees.&lt;br&gt;You must have at least one of these scopes: &#39;fees.read, setup.read, setup.manage&#39;.
     * @param $params.propertyId Filter fees by the specified property
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCustomFeesGet($params: settingsCustomFeesGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CustomFeeListModel | null>;
    settingsCustomFeesGet($params: settingsCustomFeesGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CustomFeeListModel | null>>;
    settingsCustomFeesGet($params: settingsCustomFeesGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CustomFeeListModel | null>>;
    /**
     * Create a fee.
     * Create a fee.&lt;br&gt;You must have at least one of these scopes: &#39;fees.create, setup.manage&#39;.
     * @param $params.body The definition of the fee.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsCustomFeesPost($params: settingsCustomFeesPost.Params, observe?: 'body', reportProgress?: boolean): Observable<CustomFeeCreatedModel>;
    settingsCustomFeesPost($params: settingsCustomFeesPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CustomFeeCreatedModel>>;
    settingsCustomFeesPost($params: settingsCustomFeesPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CustomFeeCreatedModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CustomFeeService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CustomFeeService>;
}
