import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CountModel } from '../model/countModel';
import { CreateCustomSubAccountModel } from '../model/createCustomSubAccountModel';
import { CustomSubAccountCreatedModel } from '../model/customSubAccountCreatedModel';
import { CustomSubAccountModel } from '../model/customSubAccountModel';
import { CustomSubAccountsListModel } from '../model/customSubAccountsListModel';
import { Operation } from '../model/operation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsSubAccountsByIdDelete {
    interface Params {
        /**
        * The ID of the sub-accounts.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsSubAccountsByIdGet {
    interface Params {
        /**
        * The ID of the sub-account.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsSubAccountsByIdHead {
    interface Params {
        /**
        * The ID of the sub-account.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsSubAccountsByIdPatch {
    interface Params {
        /**
        * The ID of the sub-account.
        */
        id: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsSubAccountsGet {
    interface Params {
        /**
        * ID of the property
        */
        propertyId: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
        */
        pageNumber?: number;
        /**
        * Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
        */
        pageSize?: number;
    }
}
export declare namespace settingsSubAccountsPost {
    interface Params {
        /**
        * The definition of the sub-account.
        */
        body: CreateCustomSubAccountModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare namespace settingsSubAccountscountGet {
    interface Params {
        /**
        * ID of the property
        */
        propertyId: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare class CustomSubAccountsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Delete a custom sub-account
     * Use this call to delete a custom sub-accounts.  When you delete a custom sub-account, the corresponding accounting accounts are either archived (if there are some transactions posted),  or deleted (if no transactions were posted).&lt;br&gt;You must have at least one of these scopes: &#39;subledger.manage, setup.manage&#39;.
     * @param $params.id The ID of the sub-accounts.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsSubAccountsByIdDelete($params: settingsSubAccountsByIdDelete.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsSubAccountsByIdDelete($params: settingsSubAccountsByIdDelete.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsSubAccountsByIdDelete($params: settingsSubAccountsByIdDelete.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Returns one sub-account.
     * Get a sub-account by ID.&lt;br&gt;You must have at least one of these scopes: &#39;subledger.read, setup.read, setup.manage&#39;.
     * @param $params.id The ID of the sub-account.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsSubAccountsByIdGet($params: settingsSubAccountsByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CustomSubAccountModel>;
    settingsSubAccountsByIdGet($params: settingsSubAccountsByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CustomSubAccountModel>>;
    settingsSubAccountsByIdGet($params: settingsSubAccountsByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CustomSubAccountModel>>;
    /**
     * Check if the sub-account exists.
     * Check if the sub-account exists.&lt;br&gt;You must have at least one of these scopes: &#39;subledger.read, setup.read, setup.manage&#39;.
     * @param $params.id The ID of the sub-account.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsSubAccountsByIdHead($params: settingsSubAccountsByIdHead.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsSubAccountsByIdHead($params: settingsSubAccountsByIdHead.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsSubAccountsByIdHead($params: settingsSubAccountsByIdHead.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Allows to modify the name of the sub-account.
     * Allows to modify the name of the sub-account.&lt;br&gt;You must have at least one of these scopes: &#39;subledger.manage, setup.manage&#39;.
     * @param $params.id The ID of the sub-account.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsSubAccountsByIdPatch($params: settingsSubAccountsByIdPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsSubAccountsByIdPatch($params: settingsSubAccountsByIdPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsSubAccountsByIdPatch($params: settingsSubAccountsByIdPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Returns a list of all sub-accounts.
     * Returns a list of all sub-accounts.&lt;br&gt;You must have at least one of these scopes: &#39;subledger.read, setup.read, setup.manage&#39;.
     * @param $params.propertyId ID of the property
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.pageNumber Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsSubAccountsGet($params: settingsSubAccountsGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CustomSubAccountsListModel | null>;
    settingsSubAccountsGet($params: settingsSubAccountsGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CustomSubAccountsListModel | null>>;
    settingsSubAccountsGet($params: settingsSubAccountsGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CustomSubAccountsListModel | null>>;
    /**
     * Create a sub-account.
     * Create a sub-account.&lt;br&gt;You must have at least one of these scopes: &#39;subledger.manage, setup.manage&#39;.
     * @param $params.body The definition of the sub-account.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsSubAccountsPost($params: settingsSubAccountsPost.Params, observe?: 'body', reportProgress?: boolean): Observable<CustomSubAccountCreatedModel>;
    settingsSubAccountsPost($params: settingsSubAccountsPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CustomSubAccountCreatedModel>>;
    settingsSubAccountsPost($params: settingsSubAccountsPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CustomSubAccountCreatedModel>>;
    /**
     * Returns number of sub-accounts.
     * Returns number of sub-account.&lt;br&gt;You must have at least one of these scopes: &#39;subledger.read, setup.read, setup.manage&#39;.
     * @param $params.propertyId ID of the property
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsSubAccountscountGet($params: settingsSubAccountscountGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CountModel>;
    settingsSubAccountscountGet($params: settingsSubAccountscountGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CountModel>>;
    settingsSubAccountscountGet($params: settingsSubAccountscountGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CountModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CustomSubAccountsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CustomSubAccountsService>;
}
