import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { FeatureSettingsModel } from '../model/featureSettingsModel';
import { Operation } from '../model/operation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsFeaturesByPropertyIdGet {
    interface Params {
        /**
        * The ID of the property.
        */
        propertyId: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsFeaturesByPropertyIdPatch {
    interface Params {
        /**
        * The ID of the property you want to toggle features for.
        */
        propertyId: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare class FeatureSettingsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get feature settings for a property.
     * Get feature settings for a property.&lt;br&gt;You must have at least one of these scopes: &#39;settings.read, setup.read, setup.manage&#39;.
     * @param $params.propertyId The ID of the property.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsFeaturesByPropertyIdGet($params: settingsFeaturesByPropertyIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<FeatureSettingsModel>;
    settingsFeaturesByPropertyIdGet($params: settingsFeaturesByPropertyIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<FeatureSettingsModel>>;
    settingsFeaturesByPropertyIdGet($params: settingsFeaturesByPropertyIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<FeatureSettingsModel>>;
    /**
     * Allows to modify feature settings
     * Here is the list of operations that are currently allowed:  - Replace areCustomRevenueSubAccountsEnabled flag  - Replace performAccountingForOpenInvoiceActions flag  - Replace showRecipientForEachLineItemOnTheInvoice flag  - Replace addCityTaxOnReservationCreation flag  - Replace maxAmountForMinimalInvoices value  - Replace invoiceNumberPattern value  - Replace advanceInvoiceNumberPattern value&lt;br&gt;You must have at least one of these scopes: &#39;features.toggle, setup.manage&#39;.
     * @param $params.propertyId The ID of the property you want to toggle features for.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsFeaturesByPropertyIdPatch($params: settingsFeaturesByPropertyIdPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsFeaturesByPropertyIdPatch($params: settingsFeaturesByPropertyIdPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsFeaturesByPropertyIdPatch($params: settingsFeaturesByPropertyIdPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<FeatureSettingsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FeatureSettingsService>;
}
