import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { InvoiceAddressCreateOrReplaceModel } from '../model/invoiceAddressCreateOrReplaceModel';
import { InvoiceAddressListModel } from '../model/invoiceAddressListModel';
import { Operation } from '../model/operation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsInvoiceAddressGet {
    interface Params {
        /**
        *
        */
        propertyIds?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsInvoiceAddressPatch {
    interface Params {
        /**
        *
        */
        propertyIds: Array<string>;
        /**
        *
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsInvoiceAddressPut {
    interface Params {
        /**
        *
        */
        propertyIds: Array<string>;
        /**
        * Address displayed on invoices.
        */
        body: InvoiceAddressCreateOrReplaceModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare class InvoiceAddressService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get invoice addresses
     * Get the list of all invoice addresses.&lt;br&gt;You must have at least one of these scopes: &#39;setup.read, setup.manage, settings.read, settings.manage&#39;.
     * @param $params.propertyIds
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsInvoiceAddressGet($params: settingsInvoiceAddressGet.Params, observe?: 'body', reportProgress?: boolean): Observable<InvoiceAddressListModel | null>;
    settingsInvoiceAddressGet($params: settingsInvoiceAddressGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<InvoiceAddressListModel | null>>;
    settingsInvoiceAddressGet($params: settingsInvoiceAddressGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<InvoiceAddressListModel | null>>;
    /**
     * Change fields in the invoice address of one or more properties.
     * Here is the list of operations that are currently allowed:  - Replace AddressLine1  - Add, replace or delete AddressLine2  - Replace PostalCode  - Replace City  - Replace CountryCode&lt;br&gt;You must have at least one of these scopes: &#39;setup.manage, settings.manage&#39;.
     * @param $params.propertyIds
     * @param $params.body
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsInvoiceAddressPatch($params: settingsInvoiceAddressPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsInvoiceAddressPatch($params: settingsInvoiceAddressPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsInvoiceAddressPatch($params: settingsInvoiceAddressPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Create or update invoice addresses for one or more properties.
     * If the address does not exist for one of the specified properties, it is created. If it exists, it is completely replaced.&lt;br&gt;You must have at least one of these scopes: &#39;setup.manage, settings.manage&#39;.
     * @param $params.propertyIds
     * @param $params.body Address displayed on invoices.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsInvoiceAddressPut($params: settingsInvoiceAddressPut.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsInvoiceAddressPut($params: settingsInvoiceAddressPut.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsInvoiceAddressPut($params: settingsInvoiceAddressPut.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<InvoiceAddressService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<InvoiceAddressService>;
}
