import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { InvoiceLineItemGroupingModel } from '../model/invoiceLineItemGroupingModel';
import { Operation } from '../model/operation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsPropertiesByPropertyIdInvoiceLineItemGroupingGet {
    interface Params {
        /**
        * The id of the property.
        */
        propertyId: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch {
    interface Params {
        /**
        * The id of the property.
        */
        propertyId: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare class InvoiceLineItemGroupingService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get invoice line item grouping configuration.
     * Retrieves the current invoice grouping settings for the specified property.&lt;br&gt;You must have this scope: &#39;admin&#39;.
     * @param $params.propertyId The id of the property.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsPropertiesByPropertyIdInvoiceLineItemGroupingGet($params: settingsPropertiesByPropertyIdInvoiceLineItemGroupingGet.Params, observe?: 'body', reportProgress?: boolean): Observable<InvoiceLineItemGroupingModel>;
    settingsPropertiesByPropertyIdInvoiceLineItemGroupingGet($params: settingsPropertiesByPropertyIdInvoiceLineItemGroupingGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<InvoiceLineItemGroupingModel>>;
    settingsPropertiesByPropertyIdInvoiceLineItemGroupingGet($params: settingsPropertiesByPropertyIdInvoiceLineItemGroupingGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<InvoiceLineItemGroupingModel>>;
    /**
     * Modify invoice line item grouping configuration.
     * Updates the invoice grouping settings for the specified property.  Here&#39;s a list of allowed operations:  - Add or replace &#39;enabled&#39; grouping types - Choose which grouping options to be available for this property  - Replace &#39;default&#39; grouping type - Choose the default grouping option to be used for invoice generation&lt;br&gt;You must have this scope: &#39;admin&#39;.
     * @param $params.propertyId The id of the property.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch($params: settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch($params: settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch($params: settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<InvoiceLineItemGroupingService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<InvoiceLineItemGroupingService>;
}
