import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { LanguagesModel } from '../model/languagesModel';
import { ReplaceLanguagesModel } from '../model/replaceLanguagesModel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsLanguagesGet {
    interface Params {
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsLanguagesPut {
    interface Params {
        /**
        * The definition of the language settings.
        */
        body: ReplaceLanguagesModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare class LanguagesService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get the language settings for the account
     * Get the language settings&lt;br&gt;You must have at least one of these scopes: &#39;settings.read, setup.read, setup.manage&#39;.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsLanguagesGet($params: settingsLanguagesGet.Params, observe?: 'body', reportProgress?: boolean): Observable<LanguagesModel>;
    settingsLanguagesGet($params: settingsLanguagesGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<LanguagesModel>>;
    settingsLanguagesGet($params: settingsLanguagesGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<LanguagesModel>>;
    /**
     * Replaces the language settings for the account
     * Use this call to modify the language settings of the account.&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.body The definition of the language settings.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsLanguagesPut($params: settingsLanguagesPut.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsLanguagesPut($params: settingsLanguagesPut.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsLanguagesPut($params: settingsLanguagesPut.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<LanguagesService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LanguagesService>;
}
