import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CountModel } from '../model/countModel';
import { CreateMarketSegmentModel } from '../model/createMarketSegmentModel';
import { MarketSegmentCreatedModel } from '../model/marketSegmentCreatedModel';
import { MarketSegmentListModel } from '../model/marketSegmentListModel';
import { MarketSegmentModel } from '../model/marketSegmentModel';
import { Operation } from '../model/operation';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsMarketSegmentsByIdDelete {
    interface Params {
        /**
        * The id of the market segment.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsMarketSegmentsByIdGet {
    interface Params {
        /**
        * The id of the market segment.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsMarketSegmentsByIdHead {
    interface Params {
        /**
        * The id of the market segment.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsMarketSegmentsByIdPatch {
    interface Params {
        /**
        * The id of the market segment to be modified.
        */
        id: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsMarketSegmentsGet {
    interface Params {
        /**
        * Return market segments with any of the specified property ids
        */
        propertyIds?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
        */
        pageNumber?: number;
        /**
        * Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
        */
        pageSize?: number;
    }
}
export declare namespace settingsMarketSegmentsPost {
    interface Params {
        /**
        * The definition of the market segment.
        */
        body: CreateMarketSegmentModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare namespace settingsMarketSegmentscountGet {
    interface Params {
        /**
        * Return market segments with any of the specified property ids
        */
        propertyIds?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare class MarketSegmentService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Delete a market segment.
     * Use this call to delete a market segment.&lt;br&gt;You must have this scope: &#39;setup.manage&#39;.
     * @param $params.id The id of the market segment.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsMarketSegmentsByIdDelete($params: settingsMarketSegmentsByIdDelete.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsMarketSegmentsByIdDelete($params: settingsMarketSegmentsByIdDelete.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsMarketSegmentsByIdDelete($params: settingsMarketSegmentsByIdDelete.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get a market segment.
     * Get a market segment by id.&lt;br&gt;You must have at least one of these scopes: &#39;setup.read, setup.manage&#39;.
     * @param $params.id The id of the market segment.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsMarketSegmentsByIdGet($params: settingsMarketSegmentsByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<MarketSegmentModel>;
    settingsMarketSegmentsByIdGet($params: settingsMarketSegmentsByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MarketSegmentModel>>;
    settingsMarketSegmentsByIdGet($params: settingsMarketSegmentsByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MarketSegmentModel>>;
    /**
     * Check if a market segment exists.
     * Check if a market segment exists by id.&lt;br&gt;You must have at least one of these scopes: &#39;setup.read, setup.manage&#39;.
     * @param $params.id The id of the market segment.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsMarketSegmentsByIdHead($params: settingsMarketSegmentsByIdHead.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsMarketSegmentsByIdHead($params: settingsMarketSegmentsByIdHead.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsMarketSegmentsByIdHead($params: settingsMarketSegmentsByIdHead.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Allows to modify market segment.
     * Here is the list of operations that are currently allowed:  - Replace name  - Add, replace and remove description  - Add, replace and remove propertyIds&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.id The id of the market segment to be modified.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsMarketSegmentsByIdPatch($params: settingsMarketSegmentsByIdPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsMarketSegmentsByIdPatch($params: settingsMarketSegmentsByIdPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsMarketSegmentsByIdPatch($params: settingsMarketSegmentsByIdPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Returns a list of all market segments, filtered by the specified parameters.
     * &lt;br&gt;You must have at least one of these scopes: &#39;setup.read, setup.manage&#39;.
     * @param $params.propertyIds Return market segments with any of the specified property ids
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.pageNumber Page number, 1-based. Default value is 1 (if this is not set or not positive). Results in 204 if there are no items on that page.
     * @param $params.pageSize Page size. If this is not set or not positive, the pageNumber is ignored and all items are returned.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsMarketSegmentsGet($params: settingsMarketSegmentsGet.Params, observe?: 'body', reportProgress?: boolean): Observable<MarketSegmentListModel | null>;
    settingsMarketSegmentsGet($params: settingsMarketSegmentsGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MarketSegmentListModel | null>>;
    settingsMarketSegmentsGet($params: settingsMarketSegmentsGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MarketSegmentListModel | null>>;
    /**
     * Create a market segment
     * &lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.body The definition of the market segment.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsMarketSegmentsPost($params: settingsMarketSegmentsPost.Params, observe?: 'body', reportProgress?: boolean): Observable<MarketSegmentCreatedModel>;
    settingsMarketSegmentsPost($params: settingsMarketSegmentsPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<MarketSegmentCreatedModel>>;
    settingsMarketSegmentsPost($params: settingsMarketSegmentsPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<MarketSegmentCreatedModel>>;
    /**
     * Returns number of market segments.
     * Returns number of market segments.&lt;br&gt;You must have at least one of these scopes: &#39;setup.read, setup.manage&#39;.
     * @param $params.propertyIds Return market segments with any of the specified property ids
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsMarketSegmentscountGet($params: settingsMarketSegmentscountGet.Params, observe?: 'body', reportProgress?: boolean): Observable<CountModel>;
    settingsMarketSegmentscountGet($params: settingsMarketSegmentscountGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CountModel>>;
    settingsMarketSegmentscountGet($params: settingsMarketSegmentscountGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CountModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<MarketSegmentService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MarketSegmentService>;
}
