import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { PropertySettingsModel } from '../model/propertySettingsModel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsPropertiesByIdGet {
    interface Params {
        /**
        * The id of the property.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare class PropertySettingsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Get property settings
     * Get base settings for a property.&lt;br&gt;You must have at least one of these scopes: &#39;settings.read, setup.read, setup.manage&#39;.
     * @param $params.id The id of the property.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsPropertiesByIdGet($params: settingsPropertiesByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<PropertySettingsModel>;
    settingsPropertiesByIdGet($params: settingsPropertiesByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<PropertySettingsModel>>;
    settingsPropertiesByIdGet($params: settingsPropertiesByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<PropertySettingsModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PropertySettingsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PropertySettingsService>;
}
