import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CreateTaxModel } from '../model/createTaxModel';
import { Operation } from '../model/operation';
import { TaxCreatedModel } from '../model/taxCreatedModel';
import { TaxListModel } from '../model/taxListModel';
import { TaxModel } from '../model/taxModel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsTaxesByIdDelete {
    interface Params {
        /**
        * The id of the tax.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsTaxesByIdGet {
    interface Params {
        /**
        * The id of the tax.
        */
        id: string;
        /**
        * 'all' or comma separated list of two-letter language codes (ISO Alpha-2)
        */
        languages?: Array<string>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsTaxesByIdPatch {
    interface Params {
        /**
        * The id of the tax to be modified.
        */
        id: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsTaxesGet {
    interface Params {
        /**
        * Filter taxes by the specified property
        */
        propertyId?: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsTaxesPost {
    interface Params {
        /**
        * The definition of the tax.
        */
        body: CreateTaxModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare class TaxService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Delete a tax.
     * Use this call to delete a tax.&lt;br&gt;You must have this scope: &#39;setup.manage&#39;.
     * @param $params.id The id of the tax.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsTaxesByIdDelete($params: settingsTaxesByIdDelete.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsTaxesByIdDelete($params: settingsTaxesByIdDelete.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsTaxesByIdDelete($params: settingsTaxesByIdDelete.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get a specific tax.
     * Get a specific tax.&lt;br&gt;You must have this scope: &#39;setup.read&#39;.
     * @param $params.id The id of the tax.
     * @param $params.languages &#39;all&#39; or comma separated list of two-letter language codes (ISO Alpha-2)
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsTaxesByIdGet($params: settingsTaxesByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<TaxModel>;
    settingsTaxesByIdGet($params: settingsTaxesByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TaxModel>>;
    settingsTaxesByIdGet($params: settingsTaxesByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TaxModel>>;
    /**
     * Allows to modify properties of a tax.
     * Here is the list of operations that are currently allowed:  - Replace name  - Replace percentValue  - Add, replace and remove subAccountId   &lt;br&gt;You must have this scope: &#39;setup.manage&#39;.
     * @param $params.id The id of the tax to be modified.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsTaxesByIdPatch($params: settingsTaxesByIdPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsTaxesByIdPatch($params: settingsTaxesByIdPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsTaxesByIdPatch($params: settingsTaxesByIdPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get all taxes.
     * Get the list of taxes.&lt;br&gt;You must have this scope: &#39;setup.read&#39;.
     * @param $params.propertyId Filter taxes by the specified property
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsTaxesGet($params: settingsTaxesGet.Params, observe?: 'body', reportProgress?: boolean): Observable<TaxListModel | null>;
    settingsTaxesGet($params: settingsTaxesGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TaxListModel | null>>;
    settingsTaxesGet($params: settingsTaxesGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TaxListModel | null>>;
    /**
     * Create a tax.
     * Create a tax.&lt;br&gt;You must have this scope: &#39;setup.manage&#39;.
     * @param $params.body The definition of the tax.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsTaxesPost($params: settingsTaxesPost.Params, observe?: 'body', reportProgress?: boolean): Observable<TaxCreatedModel>;
    settingsTaxesPost($params: settingsTaxesPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TaxCreatedModel>>;
    settingsTaxesPost($params: settingsTaxesPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TaxCreatedModel>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TaxService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TaxService>;
}
