import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CreateTimeSliceDefinitionModel } from '../model/createTimeSliceDefinitionModel';
import { Operation } from '../model/operation';
import { TimeSliceDefinitionListModel } from '../model/timeSliceDefinitionListModel';
import { TimeSliceDefinitionModel } from '../model/timeSliceDefinitionModel';
import { Configuration } from '../configuration';
import * as i0 from "@angular/core";
export declare namespace settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete {
    interface Params {
        /**
        * The id of the property.
        */
        propertyId: string;
        /**
        * The id of the time slice definition.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet {
    interface Params {
        /**
        * The id of the property.
        */
        propertyId: string;
        /**
        * The id of the time slice definition.
        */
        id: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * List of all embedded resources that should be expanded in the response. Possible values are: actions. All other values will be silently ignored.
        */
        expand?: Array<ExpandEnum>;
    }
    type ExpandEnum = 'actions';
    const ExpandEnumValues: readonly "actions"[];
}
export declare namespace settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch {
    interface Params {
        /**
        * The id of the property.
        */
        propertyId: string;
        /**
        * The id of the time slice definition.
        */
        id: string;
        /**
        * Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
        */
        body: Array<Operation>;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
    }
}
export declare namespace settingsPropertiesByPropertyIdTimeSliceDefinitionsGet {
    interface Params {
        /**
        * The id of the property.
        */
        propertyId: string;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * List of all embedded resources that should be expanded in the response. Possible values are: actions. All other values will be silently ignored.
        */
        expand?: Array<ExpandEnum>;
    }
    type ExpandEnum = 'actions';
    const ExpandEnumValues: readonly "actions"[];
}
export declare namespace settingsPropertiesByPropertyIdTimeSliceDefinitionsPost {
    interface Params {
        /**
        * The id of the property.
        */
        propertyId: string;
        /**
        * The payload of the time slice definition.
        */
        body: CreateTimeSliceDefinitionModel;
        /**
        * Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the <a href=\"https://en.wikipedia.org/wiki/ISO_8601\">ISO8601:2004</a>.This header will only take effect on development environments.
        */
        apaleoCurrentDateTime?: Date;
        /**
        * Unique key for safely retrying requests without accidentally performing the same operation twice.  We'll always send back the same response for requests made with the same key,  and keys can't be reused with different request parameters. Keys expire after 24 hours.
        */
        idempotencyKey?: string;
    }
}
export declare class TimeSliceDefinitionsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Delete a certain time slice definition
     * Use this call to delete a time slice definition. This is only possible if a time slice definition is not in-use&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.propertyId The id of the property.
     * @param $params.id The id of the time slice definition.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get a specific time slice definition
     * Get a specific time slice definition for a property. A time slice definition specifies  the pattern for recurring time slots. The time slots define when reservations  in the property can start or end.  It is used in the rate plans when managing prices for renting out the units.&lt;br&gt;You must have at least one of these scopes: &#39;settings.read, setup.read, setup.manage&#39;.
     * @param $params.propertyId The id of the property.
     * @param $params.id The id of the time slice definition.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.expand List of all embedded resources that should be expanded in the response. Possible values are: actions. All other values will be silently ignored.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet.Params, observe?: 'body', reportProgress?: boolean): Observable<TimeSliceDefinitionModel>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TimeSliceDefinitionModel>>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TimeSliceDefinitionModel>>;
    /**
     * Modifies a specific time slice definition for the property
     * Use this call to modify a time slice definition of the property.  Here is the list of operations that are currently allowed:  - Replace Name  - Replace CheckInTime (only possible if the time slice definition is not in-use)  - Replace CheckOutTime (only possible if the time slice definition is not in-use)&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.propertyId The id of the property.
     * @param $params.id The id of the time slice definition.
     * @param $params.body Define the list of operations to be applied to the resource. Learn more about JSON Patch here: http://jsonpatch.com/.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * Get time slice definitions
     * Get all time slice definitions for a property. A time slice definition specifies  the pattern for recurring time slots. The time slots define when reservations  in the property can start or end.  They are used in the rate plans when managing prices for renting out the units.&lt;br&gt;You must have at least one of these scopes: &#39;settings.read, setup.read, setup.manage&#39;.
     * @param $params.propertyId The id of the property.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.expand List of all embedded resources that should be expanded in the response. Possible values are: actions. All other values will be silently ignored.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsPropertiesByPropertyIdTimeSliceDefinitionsGet($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsGet.Params, observe?: 'body', reportProgress?: boolean): Observable<TimeSliceDefinitionListModel>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsGet($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsGet.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TimeSliceDefinitionListModel>>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsGet($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsGet.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TimeSliceDefinitionListModel>>;
    /**
     * Creates a time slice definition
     * Use this call to create a time slice definition.&lt;br&gt;You must have at least one of these scopes: &#39;settings.manage, setup.manage&#39;.
     * @param $params.propertyId The id of the property.
     * @param $params.body The payload of the time slice definition.
     * @param $params.apaleoCurrentDateTime Use this parameter to override the current date and time for the current request. Specify a date and time (without fractional second part) in UTC or with UTC offset as defined in the &lt;a href&#x3D;\&quot;https://en.wikipedia.org/wiki/ISO_8601\&quot;&gt;ISO8601:2004&lt;/a&gt;.This header will only take effect on development environments.
     * @param $params.idempotencyKey Unique key for safely retrying requests without accidentally performing the same operation twice.  We&#39;ll always send back the same response for requests made with the same key,  and keys can&#39;t be reused with different request parameters. Keys expire after 24 hours.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    settingsPropertiesByPropertyIdTimeSliceDefinitionsPost($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsPost.Params, observe?: 'body', reportProgress?: boolean): Observable<any>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsPost($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsPost.Params, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    settingsPropertiesByPropertyIdTimeSliceDefinitionsPost($params: settingsPropertiesByPropertyIdTimeSliceDefinitionsPost.Params, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TimeSliceDefinitionsService, [null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TimeSliceDefinitionsService>;
}
