import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Optional, Inject, NgModule, SkipSelf } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpUrlEncodingCodec, HttpParams, HttpHeaders } from '@angular/common/http';

/**
* CustomHttpUrlEncodingCodec
* Fix plus sign (+) not encoding, so sent as blank space
* See: https://github.com/angular/angular/issues/11058#issuecomment-247367318
*/
class CustomHttpUrlEncodingCodec extends HttpUrlEncodingCodec {
    encodeKey(k) {
        k = super.encodeKey(k);
        return k.replace(/\+/gi, '%2B');
    }
    encodeValue(v) {
        v = super.encodeValue(v);
        return v.replace(/\+/gi, '%2B');
    }
}

const BASE_PATH = new InjectionToken('basePath');
const COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};

class Configuration {
    constructor(configurationParameters = {}) {
        this.apiKeys = configurationParameters.apiKeys;
        this.username = configurationParameters.username;
        this.password = configurationParameters.password;
        this.accessToken = configurationParameters.accessToken;
        this.basePath = configurationParameters.basePath;
        this.withCredentials = configurationParameters.withCredentials;
    }
    /**
     * Select the correct content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param contentTypes - the array of content types that are available for selection
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderContentType(contentTypes) {
        if (contentTypes.length == 0) {
            return undefined;
        }
        let type = contentTypes.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return contentTypes[0];
        }
        return type;
    }
    /**
     * Select the correct accept content-type to use for a request.
     * Uses {@link Configuration#isJsonMime} to determine the correct accept content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param accepts - the array of content types that are available for selection.
     * @returns the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderAccept(accepts) {
        if (accepts.length == 0) {
            return undefined;
        }
        let type = accepts.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return accepts[0];
        }
        return type;
    }
    /**
     * Check if the given MIME is a JSON MIME.
     * JSON MIME examples:
     *   application/json
     *   application/json; charset=UTF8
     *   APPLICATION/JSON
     *   application/vnd.company+json
     * @param mime - MIME (Multipurpose Internet Mail Extensions)
     * @return True if the given MIME is JSON, false otherwise.
     */
    isJsonMime(mime) {
        const jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
        return mime != null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
    }
}

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$b(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class CapturePoliciesService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsCapturePoliciesByIdGet($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsCapturePoliciesByIdGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/capture-policies/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCapturePoliciesByIdPatch($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsCapturePoliciesByIdPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsCapturePoliciesByIdPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/capture-policies/${encodeURIComponent(String(id))}`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCapturePoliciesGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const pageNumber = $params.pageNumber;
        const pageSize = $params.pageSize;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        if (pageNumber !== undefined && pageNumber !== null) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/capture-policies`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function CapturePoliciesService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || CapturePoliciesService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: CapturePoliciesService, factory: CapturePoliciesService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(CapturePoliciesService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$a(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class CityTaxService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsCityTaxByIdDelete($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsCityTaxByIdDelete.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.delete(`${this.basePath}/settings/v0-nsfw/city-tax/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCityTaxByIdGet($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsCityTaxByIdGet.');
        }
        const languages = $params.languages;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (languages) {
            queryParameters = queryParameters.set('languages', languages.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/city-tax/${encodeURIComponent(String(id))}`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCityTaxByIdPatch($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsCityTaxByIdPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsCityTaxByIdPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/city-tax/${encodeURIComponent(String(id))}`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCityTaxGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/city-tax`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCityTaxPost($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsCityTaxPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/settings/v0-nsfw/city-tax`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function CityTaxService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || CityTaxService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: CityTaxService, factory: CityTaxService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(CityTaxService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$9(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class CustomFeeService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsCustomFeesByIdDelete($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsCustomFeesByIdDelete.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.delete(`${this.basePath}/settings/v0-nsfw/custom-fees/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCustomFeesByIdGet($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsCustomFeesByIdGet.');
        }
        const languages = $params.languages;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (languages) {
            queryParameters = queryParameters.set('languages', languages.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/custom-fees/${encodeURIComponent(String(id))}`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCustomFeesByIdPatch($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsCustomFeesByIdPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsCustomFeesByIdPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/custom-fees/${encodeURIComponent(String(id))}`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCustomFeesGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/custom-fees`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsCustomFeesPost($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsCustomFeesPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/settings/v0-nsfw/custom-fees`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function CustomFeeService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || CustomFeeService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: CustomFeeService, factory: CustomFeeService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(CustomFeeService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$8(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class CustomSubAccountsService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsSubAccountsByIdDelete($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsSubAccountsByIdDelete.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.delete(`${this.basePath}/settings/v0-nsfw/sub-accounts/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsSubAccountsByIdGet($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsSubAccountsByIdGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/sub-accounts/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsSubAccountsByIdHead($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsSubAccountsByIdHead.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.head(`${this.basePath}/settings/v0-nsfw/sub-accounts/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsSubAccountsByIdPatch($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsSubAccountsByIdPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsSubAccountsByIdPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/sub-accounts/${encodeURIComponent(String(id))}`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsSubAccountsGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsSubAccountsGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const pageNumber = $params.pageNumber;
        const pageSize = $params.pageSize;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        if (pageNumber !== undefined && pageNumber !== null) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/sub-accounts`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsSubAccountsPost($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsSubAccountsPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/settings/v0-nsfw/sub-accounts`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsSubAccountscountGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsSubAccountscountGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/sub-accounts/$count`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function CustomSubAccountsService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || CustomSubAccountsService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: CustomSubAccountsService, factory: CustomSubAccountsService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(CustomSubAccountsService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$7(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class FeatureSettingsService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsFeaturesByPropertyIdGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsFeaturesByPropertyIdGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/features/${encodeURIComponent(String(propertyId))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsFeaturesByPropertyIdPatch($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsFeaturesByPropertyIdPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsFeaturesByPropertyIdPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/features/${encodeURIComponent(String(propertyId))}`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function FeatureSettingsService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || FeatureSettingsService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: FeatureSettingsService, factory: FeatureSettingsService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(FeatureSettingsService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$6(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class InvoiceAddressService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsInvoiceAddressGet($params, observe = 'body', reportProgress = false) {
        const propertyIds = $params.propertyIds;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/invoice-address`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsInvoiceAddressPatch($params, observe = 'body', reportProgress = false) {
        const propertyIds = $params.propertyIds;
        if (propertyIds === null || propertyIds === undefined) {
            throw new Error('Required parameter propertyIds was null or undefined when calling settingsInvoiceAddressPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsInvoiceAddressPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/invoice-address`, body, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsInvoiceAddressPut($params, observe = 'body', reportProgress = false) {
        const propertyIds = $params.propertyIds;
        if (propertyIds === null || propertyIds === undefined) {
            throw new Error('Required parameter propertyIds was null or undefined when calling settingsInvoiceAddressPut.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsInvoiceAddressPut.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(`${this.basePath}/settings/v0-nsfw/invoice-address`, body, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function InvoiceAddressService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || InvoiceAddressService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: InvoiceAddressService, factory: InvoiceAddressService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(InvoiceAddressService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$5(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class InvoiceLineItemGroupingService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsPropertiesByPropertyIdInvoiceLineItemGroupingGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsPropertiesByPropertyIdInvoiceLineItemGroupingGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/properties/${encodeURIComponent(String(propertyId))}/invoice-line-item-grouping`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsPropertiesByPropertyIdInvoiceLineItemGroupingPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/properties/${encodeURIComponent(String(propertyId))}/invoice-line-item-grouping`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function InvoiceLineItemGroupingService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || InvoiceLineItemGroupingService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: InvoiceLineItemGroupingService, factory: InvoiceLineItemGroupingService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(InvoiceLineItemGroupingService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$4(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class LanguagesService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsLanguagesGet($params, observe = 'body', reportProgress = false) {
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/languages`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsLanguagesPut($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsLanguagesPut.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(`${this.basePath}/settings/v0-nsfw/languages`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function LanguagesService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || LanguagesService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: LanguagesService, factory: LanguagesService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(LanguagesService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$3(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class MarketSegmentService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsMarketSegmentsByIdDelete($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsMarketSegmentsByIdDelete.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.delete(`${this.basePath}/settings/v0-nsfw/market-segments/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsMarketSegmentsByIdGet($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsMarketSegmentsByIdGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/market-segments/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsMarketSegmentsByIdHead($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsMarketSegmentsByIdHead.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.head(`${this.basePath}/settings/v0-nsfw/market-segments/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsMarketSegmentsByIdPatch($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsMarketSegmentsByIdPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsMarketSegmentsByIdPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/market-segments/${encodeURIComponent(String(id))}`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsMarketSegmentsGet($params, observe = 'body', reportProgress = false) {
        const propertyIds = $params.propertyIds;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const pageNumber = $params.pageNumber;
        const pageSize = $params.pageSize;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        if (pageNumber !== undefined && pageNumber !== null) {
            queryParameters = queryParameters.set('pageNumber', pageNumber);
        }
        if (pageSize !== undefined && pageSize !== null) {
            queryParameters = queryParameters.set('pageSize', pageSize);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/market-segments`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsMarketSegmentsPost($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsMarketSegmentsPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/settings/v0-nsfw/market-segments`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsMarketSegmentscountGet($params, observe = 'body', reportProgress = false) {
        const propertyIds = $params.propertyIds;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyIds) {
            queryParameters = queryParameters.set('propertyIds', propertyIds.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/market-segments/$count`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function MarketSegmentService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || MarketSegmentService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: MarketSegmentService, factory: MarketSegmentService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(MarketSegmentService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$2(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class PropertySettingsService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsPropertiesByIdGet($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsPropertiesByIdGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/properties/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function PropertySettingsService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || PropertySettingsService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: PropertySettingsService, factory: PropertySettingsService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(PropertySettingsService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append$1(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
class TaxService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsTaxesByIdDelete($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsTaxesByIdDelete.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.delete(`${this.basePath}/settings/v0-nsfw/taxes/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsTaxesByIdGet($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsTaxesByIdGet.');
        }
        const languages = $params.languages;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (languages) {
            queryParameters = queryParameters.set('languages', languages.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/taxes/${encodeURIComponent(String(id))}`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsTaxesByIdPatch($params, observe = 'body', reportProgress = false) {
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsTaxesByIdPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsTaxesByIdPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/taxes/${encodeURIComponent(String(id))}`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsTaxesGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (propertyId !== undefined && propertyId !== null) {
            queryParameters = queryParameters.set('propertyId', propertyId);
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/taxes`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsTaxesPost($params, observe = 'body', reportProgress = false) {
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsTaxesPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/settings/v0-nsfw/taxes`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function TaxService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || TaxService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: TaxService, factory: TaxService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(TaxService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
function append(formParams, param, value) {
    if (formParams instanceof FormData) {
        formParams.append(param, value);
        return formParams;
    }
    else if (formParams instanceof HttpParams) {
        return formParams.append(param, value);
    }
    formParams.append(param, value);
    return formParams;
}
;
var settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet;
(function (settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet) {
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet.ExpandEnumValues = Object.freeze(['actions']);
})(settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet || (settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet = {}));
var settingsPropertiesByPropertyIdTimeSliceDefinitionsGet;
(function (settingsPropertiesByPropertyIdTimeSliceDefinitionsGet) {
    settingsPropertiesByPropertyIdTimeSliceDefinitionsGet.ExpandEnumValues = Object.freeze(['actions']);
})(settingsPropertiesByPropertyIdTimeSliceDefinitionsGet || (settingsPropertiesByPropertyIdTimeSliceDefinitionsGet = {}));
class TimeSliceDefinitionsService {
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://localhost';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete.');
        }
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdDelete.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.delete(`${this.basePath}/settings/v0-nsfw/properties/${encodeURIComponent(String(propertyId))}/time-slice-definitions/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet.');
        }
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const expand = $params.expand;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (expand) {
            queryParameters = queryParameters.set('expand', expand.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/properties/${encodeURIComponent(String(propertyId))}/time-slice-definitions/${encodeURIComponent(String(id))}`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch.');
        }
        const id = $params.id;
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdPatch.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.patch(`${this.basePath}/settings/v0-nsfw/properties/${encodeURIComponent(String(propertyId))}/time-slice-definitions/${encodeURIComponent(String(id))}`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsPropertiesByPropertyIdTimeSliceDefinitionsGet($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsGet.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const expand = $params.expand;
        let queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (expand) {
            queryParameters = queryParameters.set('expand', expand.join(COLLECTION_FORMATS['csv']));
        }
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [];
        return this.httpClient.get(`${this.basePath}/settings/v0-nsfw/properties/${encodeURIComponent(String(propertyId))}/time-slice-definitions`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    settingsPropertiesByPropertyIdTimeSliceDefinitionsPost($params, observe = 'body', reportProgress = false) {
        const propertyId = $params.propertyId;
        if (propertyId === null || propertyId === undefined) {
            throw new Error('Required parameter propertyId was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsPost.');
        }
        const body = $params.body;
        if (body === null || body === undefined) {
            throw new Error('Required parameter body was null or undefined when calling settingsPropertiesByPropertyIdTimeSliceDefinitionsPost.');
        }
        const apaleoCurrentDateTime = $params.apaleoCurrentDateTime;
        const idempotencyKey = $params.idempotencyKey;
        let headers = this.defaultHeaders;
        if (apaleoCurrentDateTime !== undefined && apaleoCurrentDateTime !== null) {
            headers = headers.set('Apaleo-Current-DateTime', String(apaleoCurrentDateTime));
        }
        if (idempotencyKey !== undefined && idempotencyKey !== null) {
            headers = headers.set('Idempotency-Key', String(idempotencyKey));
        }
        // authentication (oauth2) required
        if (this.configuration.accessToken) {
            const accessToken = typeof this.configuration.accessToken === 'function'
                ? this.configuration.accessToken()
                : this.configuration.accessToken;
            headers = headers.set('Authorization', 'Bearer ' + accessToken);
        }
        // to determine the Accept header
        let httpHeaderAccepts = [
            'application/json'
        ];
        const httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const consumes = [
            'application/json'
        ];
        const httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/settings/v0-nsfw/properties/${encodeURIComponent(String(propertyId))}/time-slice-definitions`, body, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    static { this.ɵfac = function TimeSliceDefinitionsService_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || TimeSliceDefinitionsService)(i0.ɵɵinject(i1.HttpClient), i0.ɵɵinject(BASE_PATH, 8), i0.ɵɵinject(Configuration, 8)); }; }
    static { this.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: TimeSliceDefinitionsService, factory: TimeSliceDefinitionsService.ɵfac }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(TimeSliceDefinitionsService, [{
        type: Injectable
    }], () => [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                type: Optional
            }, {
                type: Inject,
                args: [BASE_PATH]
            }] }, { type: Configuration, decorators: [{
                type: Optional
            }] }], null); })();

const APIS = [CapturePoliciesService, CityTaxService, CustomFeeService, CustomSubAccountsService, FeatureSettingsService, InvoiceAddressService, InvoiceLineItemGroupingService, LanguagesService, MarketSegmentService, PropertySettingsService, TaxService, TimeSliceDefinitionsService];

var ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason;
(function (ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason) {
    ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason.ActionEnumValues = Object.freeze(['ModifyCheckInCheckOutTime', 'Delete']);
})(ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason || (ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason = {}));
(function (ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason) {
    ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason.$metaData = {
        action: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason.ActionEnumValues,
            isPrimitiveType: true,
        }),
        isAllowed: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        reasons: Object.freeze({
            type: 'Array<ActionReasonModelNotAllowedTimeSliceDefinitionActionReason>',
            isListContainer: true,
        }),
    };
})(ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason || (ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ActionReasonModelNotAllowedTimeSliceDefinitionActionReason;
(function (ActionReasonModelNotAllowedTimeSliceDefinitionActionReason) {
    ActionReasonModelNotAllowedTimeSliceDefinitionActionReason.CodeEnumValues = Object.freeze(['ModifyCheckInCheckOutTimeNotAllowedForUsedTimeSliceDefinition', 'DeleteIsNotAllowedForUsedTimeSliceDefinition']);
})(ActionReasonModelNotAllowedTimeSliceDefinitionActionReason || (ActionReasonModelNotAllowedTimeSliceDefinitionActionReason = {}));
(function (ActionReasonModelNotAllowedTimeSliceDefinitionActionReason) {
    ActionReasonModelNotAllowedTimeSliceDefinitionActionReason.$metaData = {
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: ActionReasonModelNotAllowedTimeSliceDefinitionActionReason.CodeEnumValues,
            isPrimitiveType: true,
        }),
        message: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(ActionReasonModelNotAllowedTimeSliceDefinitionActionReason || (ActionReasonModelNotAllowedTimeSliceDefinitionActionReason = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CapturePolicyItemModel;
(function (CapturePolicyItemModel) {
    CapturePolicyItemModel.CapturePaymentEnumValues = Object.freeze(['Manual', 'CheckIn', 'CheckOut']);
})(CapturePolicyItemModel || (CapturePolicyItemModel = {}));
(function (CapturePolicyItemModel) {
    CapturePolicyItemModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        captureNoShowFee: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        captureCancellationFee: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        capturePrepayment: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        postOtaBankTransferOnCheckOut: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        capturePayment: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CapturePolicyItemModel.CapturePaymentEnumValues,
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CapturePolicyItemModel || (CapturePolicyItemModel = {}));

var CapturePolicyListModel;
(function (CapturePolicyListModel) {
    CapturePolicyListModel.$metaData = {
        capturePolicies: Object.freeze({
            isRequired: true,
            type: 'Array<CapturePolicyItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(CapturePolicyListModel || (CapturePolicyListModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CapturePolicyModel;
(function (CapturePolicyModel) {
    CapturePolicyModel.CapturePaymentEnumValues = Object.freeze(['Manual', 'CheckIn', 'CheckOut']);
})(CapturePolicyModel || (CapturePolicyModel = {}));
(function (CapturePolicyModel) {
    CapturePolicyModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        captureNoShowFee: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        captureCancellationFee: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        capturePrepayment: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        postOtaBankTransferOnCheckOut: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        capturePayment: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CapturePolicyModel.CapturePaymentEnumValues,
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CapturePolicyModel || (CapturePolicyModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var DistributionChannelTaxConfigModel;
(function (DistributionChannelTaxConfigModel) {
    DistributionChannelTaxConfigModel.ChannelCodeEnumValues = Object.freeze(['Direct', 'BookingCom', 'Ibe', 'ChannelManager', 'Expedia', 'Homelike', 'Hrs', 'AltoVita', 'DesVu']);
    DistributionChannelTaxConfigModel.RemittanceResponsibilityEnumValues = Object.freeze(['Hotel', 'Ota']);
})(DistributionChannelTaxConfigModel || (DistributionChannelTaxConfigModel = {}));
(function (DistributionChannelTaxConfigModel) {
    DistributionChannelTaxConfigModel.$metaData = {
        channelCode: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: DistributionChannelTaxConfigModel.ChannelCodeEnumValues,
            isPrimitiveType: true,
        }),
        sources: Object.freeze({
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
        remittanceResponsibility: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: DistributionChannelTaxConfigModel.RemittanceResponsibilityEnumValues,
            isPrimitiveType: true,
        }),
    };
})(DistributionChannelTaxConfigModel || (DistributionChannelTaxConfigModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CityTaxConfigModel;
(function (CityTaxConfigModel) {
    CityTaxConfigModel.$metaData = {
        distributionChannel: Object.freeze({
            type: 'DistributionChannelTaxConfigModel',
            metaData: DistributionChannelTaxConfigModel.$metaData
        }),
    };
})(CityTaxConfigModel || (CityTaxConfigModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CityTaxCreatedModel;
(function (CityTaxCreatedModel) {
    CityTaxCreatedModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CityTaxCreatedModel || (CityTaxCreatedModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CityTaxItemModel;
(function (CityTaxItemModel) {
    CityTaxItemModel.TypeEnumValues = Object.freeze(['PercentOfGross', 'PercentOfNet', 'PerRoomPerNight', 'PerPersonPerNight', 'PerPersonPerNightBasedOnNetPrice', 'PerPersonPerNightBasedOnGrossPrice']);
    CityTaxItemModel.TaxHandlingTypeEnumValues = Object.freeze(['BeforeTax', 'AfterTax']);
    CityTaxItemModel.VatTypeEnumValues = Object.freeze(['Null', 'VeryReduced', 'Reduced', 'Normal', 'Without', 'Special', 'ReducedCovid19', 'NormalCovid19', 'Mixed']);
})(CityTaxItemModel || (CityTaxItemModel = {}));
(function (CityTaxItemModel) {
    CityTaxItemModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        description: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CityTaxItemModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
        taxHandlingType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CityTaxItemModel.TaxHandlingTypeEnumValues,
            isPrimitiveType: true,
        }),
        value: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        vatType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CityTaxItemModel.VatTypeEnumValues,
            isPrimitiveType: true,
        }),
        priority: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        includeCityTaxInRateAmount: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
    };
})(CityTaxItemModel || (CityTaxItemModel = {}));

var CityTaxListModel;
(function (CityTaxListModel) {
    CityTaxListModel.$metaData = {
        cityTaxes: Object.freeze({
            isRequired: true,
            type: 'Array<CityTaxItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(CityTaxListModel || (CityTaxListModel = {}));

var CityTaxModel;
(function (CityTaxModel) {
    CityTaxModel.TypeEnumValues = Object.freeze(['PercentOfGross', 'PercentOfNet', 'PerRoomPerNight', 'PerPersonPerNight', 'PerPersonPerNightBasedOnNetPrice', 'PerPersonPerNightBasedOnGrossPrice']);
    CityTaxModel.TaxHandlingTypeEnumValues = Object.freeze(['BeforeTax', 'AfterTax']);
    CityTaxModel.VatTypeEnumValues = Object.freeze(['Null', 'VeryReduced', 'Reduced', 'Normal', 'Without', 'Special', 'ReducedCovid19', 'NormalCovid19', 'Mixed']);
})(CityTaxModel || (CityTaxModel = {}));
(function (CityTaxModel) {
    CityTaxModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            type: '{ [key: string]: string; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        description: Object.freeze({
            isRequired: true,
            type: '{ [key: string]: string; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CityTaxModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
        taxHandlingType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CityTaxModel.TaxHandlingTypeEnumValues,
            isPrimitiveType: true,
        }),
        value: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        limit: Object.freeze({
            type: 'number',
            isPrimitiveType: true,
        }),
        subcategories: Object.freeze({
            type: 'Array<CityTaxSubcategoryModel>',
            isListContainer: true,
        }),
        pricingRules: Object.freeze({
            type: 'Array<CityTaxPricingRuleModel>',
            isListContainer: true,
        }),
        vatType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CityTaxModel.VatTypeEnumValues,
            isPrimitiveType: true,
        }),
        priority: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        includeCityTaxInRateAmount: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        ignoredFor: Object.freeze({
            type: 'Array<CityTaxConfigModel>',
            isListContainer: true,
        }),
    };
})(CityTaxModel || (CityTaxModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CityTaxPricingRuleModel;
(function (CityTaxPricingRuleModel) {
    CityTaxPricingRuleModel.$metaData = {
        value: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        maxPrice: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(CityTaxPricingRuleModel || (CityTaxPricingRuleModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CityTaxSubcategoryAgeModel;
(function (CityTaxSubcategoryAgeModel) {
    CityTaxSubcategoryAgeModel.$metaData = {
        min: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        max: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(CityTaxSubcategoryAgeModel || (CityTaxSubcategoryAgeModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CityTaxSubcategoryModel;
(function (CityTaxSubcategoryModel) {
    CityTaxSubcategoryModel.$metaData = {
        name: Object.freeze({
            isRequired: true,
            type: '{ [key: string]: string; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        value: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        age: Object.freeze({
            isRequired: true,
            type: 'CityTaxSubcategoryAgeModel',
            metaData: CityTaxSubcategoryAgeModel.$metaData
        }),
    };
})(CityTaxSubcategoryModel || (CityTaxSubcategoryModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CountModel;
(function (CountModel) {
    CountModel.$metaData = {
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(CountModel || (CountModel = {}));

var CreateCityTaxModel;
(function (CreateCityTaxModel) {
    CreateCityTaxModel.TypeEnumValues = Object.freeze(['PercentOfGross', 'PercentOfNet', 'PerRoomPerNight', 'PerPersonPerNight', 'PerPersonPerNightBasedOnNetPrice', 'PerPersonPerNightBasedOnGrossPrice']);
    CreateCityTaxModel.TaxHandlingTypeEnumValues = Object.freeze(['BeforeTax', 'AfterTax']);
    CreateCityTaxModel.VatTypeEnumValues = Object.freeze(['Null', 'VeryReduced', 'Reduced', 'Normal', 'Without', 'Special', 'ReducedCovid19', 'NormalCovid19', 'Mixed']);
})(CreateCityTaxModel || (CreateCityTaxModel = {}));
(function (CreateCityTaxModel) {
    CreateCityTaxModel.$metaData = {
        name: Object.freeze({
            isRequired: true,
            type: '{ [key: string]: string; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        description: Object.freeze({
            isRequired: true,
            type: '{ [key: string]: string; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateCityTaxModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
        taxHandlingType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateCityTaxModel.TaxHandlingTypeEnumValues,
            isPrimitiveType: true,
        }),
        value: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        vatType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateCityTaxModel.VatTypeEnumValues,
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        priority: Object.freeze({
            type: 'number',
            isPrimitiveType: true,
        }),
        includeCityTaxInRateAmount: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        limit: Object.freeze({
            type: 'number',
            isPrimitiveType: true,
        }),
        subcategories: Object.freeze({
            type: 'Array<CityTaxSubcategoryModel>',
            isListContainer: true,
        }),
        pricingRules: Object.freeze({
            type: 'Array<CityTaxPricingRuleModel>',
            isListContainer: true,
        }),
        ignoredFor: Object.freeze({
            type: 'Array<CityTaxConfigModel>',
            isListContainer: true,
        }),
    };
})(CreateCityTaxModel || (CreateCityTaxModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CreateCustomFeeModel;
(function (CreateCustomFeeModel) {
    CreateCustomFeeModel.ServiceTypeEnumValues = Object.freeze(['Other', 'Accommodation', 'FoodAndBeverages']);
    CreateCustomFeeModel.VatTypeEnumValues = Object.freeze(['Null', 'VeryReduced', 'Reduced', 'Normal', 'Without', 'Special', 'ReducedCovid19', 'NormalCovid19', 'Mixed']);
})(CreateCustomFeeModel || (CreateCustomFeeModel = {}));
(function (CreateCustomFeeModel) {
    CreateCustomFeeModel.$metaData = {
        code: Object.freeze({
            isRequired: true,
            minLength: 3,
            maxLength: 10,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            type: '{ [key: string]: string; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        percentValue: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        serviceType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateCustomFeeModel.ServiceTypeEnumValues,
            isPrimitiveType: true,
        }),
        vatType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateCustomFeeModel.VatTypeEnumValues,
            isPrimitiveType: true,
        }),
        subAccountId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CreateCustomFeeModel || (CreateCustomFeeModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CreateCustomSubAccountModel;
(function (CreateCustomSubAccountModel) {
    CreateCustomSubAccountModel.TypeEnumValues = Object.freeze(['Other', 'Accommodation', 'FoodAndBeverages']);
})(CreateCustomSubAccountModel || (CreateCustomSubAccountModel = {}));
(function (CreateCustomSubAccountModel) {
    CreateCustomSubAccountModel.$metaData = {
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateCustomSubAccountModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
    };
})(CreateCustomSubAccountModel || (CreateCustomSubAccountModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CreateMarketSegmentModel;
(function (CreateMarketSegmentModel) {
    CreateMarketSegmentModel.$metaData = {
        code: Object.freeze({
            isRequired: true,
            minLength: 3,
            maxLength: 10,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        description: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyIds: Object.freeze({
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
    };
})(CreateMarketSegmentModel || (CreateMarketSegmentModel = {}));

var CreateTaxModel;
(function (CreateTaxModel) {
    CreateTaxModel.ServiceTypeEnumValues = Object.freeze(['Other', 'Accommodation', 'FoodAndBeverages']);
})(CreateTaxModel || (CreateTaxModel = {}));
(function (CreateTaxModel) {
    CreateTaxModel.$metaData = {
        code: Object.freeze({
            isRequired: true,
            minLength: 3,
            maxLength: 10,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            type: '{ [key: string]: string; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        serviceType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateTaxModel.ServiceTypeEnumValues,
            isPrimitiveType: true,
        }),
        isSubjectToTax: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        subAccountId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        appliedTo: Object.freeze({
            type: 'Array<TaxConfigModel>',
            isListContainer: true,
        }),
        ignoredFor: Object.freeze({
            type: 'Array<TaxConfigModel>',
            isListContainer: true,
        }),
        taxPeriods: Object.freeze({
            isRequired: true,
            type: 'Array<TaxPeriodModel>',
            isListContainer: true,
        }),
    };
})(CreateTaxModel || (CreateTaxModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CreateTimeSliceDefinitionModel;
(function (CreateTimeSliceDefinitionModel) {
    CreateTimeSliceDefinitionModel.TemplateEnumValues = Object.freeze(['DayUse', 'OverNight']);
})(CreateTimeSliceDefinitionModel || (CreateTimeSliceDefinitionModel = {}));
(function (CreateTimeSliceDefinitionModel) {
    CreateTimeSliceDefinitionModel.$metaData = {
        name: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        template: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CreateTimeSliceDefinitionModel.TemplateEnumValues,
            isPrimitiveType: true,
        }),
        checkInTime: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        checkOutTime: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CreateTimeSliceDefinitionModel || (CreateTimeSliceDefinitionModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CustomFeeCreatedModel;
(function (CustomFeeCreatedModel) {
    CustomFeeCreatedModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CustomFeeCreatedModel || (CustomFeeCreatedModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CustomFeeItemModel;
(function (CustomFeeItemModel) {
    CustomFeeItemModel.ServiceTypeEnumValues = Object.freeze(['Other', 'Accommodation', 'FoodAndBeverages']);
    CustomFeeItemModel.VatTypeEnumValues = Object.freeze(['Null', 'VeryReduced', 'Reduced', 'Normal', 'Without', 'Special', 'ReducedCovid19', 'NormalCovid19', 'Mixed']);
})(CustomFeeItemModel || (CustomFeeItemModel = {}));
(function (CustomFeeItemModel) {
    CustomFeeItemModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        percentValue: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        serviceType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CustomFeeItemModel.ServiceTypeEnumValues,
            isPrimitiveType: true,
        }),
        vatType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CustomFeeItemModel.VatTypeEnumValues,
            isPrimitiveType: true,
        }),
        subAccountId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CustomFeeItemModel || (CustomFeeItemModel = {}));

var CustomFeeListModel;
(function (CustomFeeListModel) {
    CustomFeeListModel.$metaData = {
        fees: Object.freeze({
            isRequired: true,
            type: 'Array<CustomFeeItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(CustomFeeListModel || (CustomFeeListModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CustomFeeModel;
(function (CustomFeeModel) {
    CustomFeeModel.ServiceTypeEnumValues = Object.freeze(['Other', 'Accommodation', 'FoodAndBeverages']);
    CustomFeeModel.VatTypeEnumValues = Object.freeze(['Null', 'VeryReduced', 'Reduced', 'Normal', 'Without', 'Special', 'ReducedCovid19', 'NormalCovid19', 'Mixed']);
})(CustomFeeModel || (CustomFeeModel = {}));
(function (CustomFeeModel) {
    CustomFeeModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            type: '{ [key: string]: string; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        percentValue: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        serviceType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CustomFeeModel.ServiceTypeEnumValues,
            isPrimitiveType: true,
        }),
        vatType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CustomFeeModel.VatTypeEnumValues,
            isPrimitiveType: true,
        }),
        subAccountId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CustomFeeModel || (CustomFeeModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CustomSubAccountCreatedModel;
(function (CustomSubAccountCreatedModel) {
    CustomSubAccountCreatedModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(CustomSubAccountCreatedModel || (CustomSubAccountCreatedModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CustomSubAccountModel;
(function (CustomSubAccountModel) {
    CustomSubAccountModel.TypeEnumValues = Object.freeze(['Other', 'Accommodation', 'FoodAndBeverages']);
})(CustomSubAccountModel || (CustomSubAccountModel = {}));
(function (CustomSubAccountModel) {
    CustomSubAccountModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        type: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: CustomSubAccountModel.TypeEnumValues,
            isPrimitiveType: true,
        }),
    };
})(CustomSubAccountModel || (CustomSubAccountModel = {}));

var CustomSubAccountsListModel;
(function (CustomSubAccountsListModel) {
    CustomSubAccountsListModel.$metaData = {
        subAccounts: Object.freeze({
            isRequired: true,
            type: 'Array<CustomSubAccountModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(CustomSubAccountsListModel || (CustomSubAccountsListModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var FeatureSettingsModel;
(function (FeatureSettingsModel) {
    FeatureSettingsModel.InvoiceLineItemGroupingTypeEnumValues = Object.freeze(['ShowIncludedServices', 'DoNotShowIncludedServices', 'NoGrouping']);
})(FeatureSettingsModel || (FeatureSettingsModel = {}));
(function (FeatureSettingsModel) {
    FeatureSettingsModel.$metaData = {
        invoiceLineItemGroupingType: Object.freeze({
            type: 'string',
            isEnum: true,
            allowedEnumValues: FeatureSettingsModel.InvoiceLineItemGroupingTypeEnumValues,
            isPrimitiveType: true,
        }),
        fiscalizationConfigured: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        areTaxesEnabled: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        areCustomRevenueSubAccountsEnabled: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        performAccountingForOpenInvoiceActions: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        showRecipientForEachLineItemOnTheInvoice: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        maxAmountForMinimalInvoices: Object.freeze({
            type: 'number',
            isPrimitiveType: true,
        }),
        invoiceNumberPattern: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        advanceInvoiceNumberPattern: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(FeatureSettingsModel || (FeatureSettingsModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var InvoiceAddressCreateOrReplaceModel;
(function (InvoiceAddressCreateOrReplaceModel) {
    InvoiceAddressCreateOrReplaceModel.$metaData = {
        addressLine1: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        addressLine2: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        postalCode: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        city: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        regionCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        countryCode: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(InvoiceAddressCreateOrReplaceModel || (InvoiceAddressCreateOrReplaceModel = {}));

var InvoiceAddressListModel;
(function (InvoiceAddressListModel) {
    InvoiceAddressListModel.$metaData = {
        addresses: Object.freeze({
            isRequired: true,
            type: 'Array<InvoiceAddressModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(InvoiceAddressListModel || (InvoiceAddressListModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var InvoiceAddressModel;
(function (InvoiceAddressModel) {
    InvoiceAddressModel.$metaData = {
        addressLine1: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        addressLine2: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        postalCode: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        city: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        regionCode: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        countryCode: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(InvoiceAddressModel || (InvoiceAddressModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var InvoiceLineItemGroupingModel;
(function (InvoiceLineItemGroupingModel) {
    InvoiceLineItemGroupingModel.EnabledEnumValues = Object.freeze(['NoGrouping', 'ByCharge', 'ByRatePlanDetailed', 'ByRatePlanSimplified']);
    InvoiceLineItemGroupingModel.DefaultEnumValues = Object.freeze(['NoGrouping', 'ByCharge', 'ByRatePlanDetailed', 'ByRatePlanSimplified']);
})(InvoiceLineItemGroupingModel || (InvoiceLineItemGroupingModel = {}));
(function (InvoiceLineItemGroupingModel) {
    InvoiceLineItemGroupingModel.$metaData = {
        enabled: Object.freeze({
            isRequired: true,
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
        _default: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: InvoiceLineItemGroupingModel.DefaultEnumValues,
            isPrimitiveType: true,
        }),
    };
})(InvoiceLineItemGroupingModel || (InvoiceLineItemGroupingModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var LanguageModel;
(function (LanguageModel) {
    LanguageModel.$metaData = {
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        _default: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        mandatory: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
    };
})(LanguageModel || (LanguageModel = {}));

var LanguagesModel;
(function (LanguagesModel) {
    LanguagesModel.$metaData = {
        languages: Object.freeze({
            isRequired: true,
            type: 'Array<LanguageModel>',
            isListContainer: true,
        }),
    };
})(LanguagesModel || (LanguagesModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MarketSegmentCreatedModel;
(function (MarketSegmentCreatedModel) {
    MarketSegmentCreatedModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(MarketSegmentCreatedModel || (MarketSegmentCreatedModel = {}));

var MarketSegmentListModel;
(function (MarketSegmentListModel) {
    MarketSegmentListModel.$metaData = {
        marketSegments: Object.freeze({
            isRequired: true,
            type: 'Array<MarketSegmentModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(MarketSegmentListModel || (MarketSegmentListModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MarketSegmentModel;
(function (MarketSegmentModel) {
    MarketSegmentModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        description: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyIds: Object.freeze({
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
    };
})(MarketSegmentModel || (MarketSegmentModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var MessageItemCollection;
(function (MessageItemCollection) {
    MessageItemCollection.$metaData = {
        messages: Object.freeze({
            type: 'Array<string>',
            isPrimitiveType: true,
            isListContainer: true,
        }),
    };
})(MessageItemCollection || (MessageItemCollection = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var Operation;
(function (Operation) {
    Operation.$metaData = {
        value: Object.freeze({
            type: 'any',
            isPrimitiveType: true,
        }),
        path: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        op: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        from: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(Operation || (Operation = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var PropertySettingsModel;
(function (PropertySettingsModel) {
    PropertySettingsModel.$metaData = {
        timeZone: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        currency: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(PropertySettingsModel || (PropertySettingsModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var ReplaceLanguageModel;
(function (ReplaceLanguageModel) {
    ReplaceLanguageModel.$metaData = {
        code: Object.freeze({
            isRequired: true,
            minLength: 2,
            maxLength: 2,
            type: 'string',
            isPrimitiveType: true,
        }),
        mandatory: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
    };
})(ReplaceLanguageModel || (ReplaceLanguageModel = {}));

var ReplaceLanguagesModel;
(function (ReplaceLanguagesModel) {
    ReplaceLanguagesModel.$metaData = {
        languages: Object.freeze({
            isRequired: true,
            type: 'Array<ReplaceLanguageModel>',
            isListContainer: true,
        }),
    };
})(ReplaceLanguagesModel || (ReplaceLanguagesModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var TaxConfigModel;
(function (TaxConfigModel) {
    TaxConfigModel.ServiceTypeEnumValues = Object.freeze(['Other', 'Accommodation', 'FoodAndBeverages', 'CancellationFees', 'NoShow', 'CityTax', 'SecondCityTax']);
})(TaxConfigModel || (TaxConfigModel = {}));
(function (TaxConfigModel) {
    TaxConfigModel.$metaData = {
        serviceType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: TaxConfigModel.ServiceTypeEnumValues,
            isPrimitiveType: true,
        }),
        subAccountId: Object.freeze({
            type: 'string',
            isPrimitiveType: true,
        }),
        distributionChannel: Object.freeze({
            type: 'DistributionChannelTaxConfigModel',
            metaData: DistributionChannelTaxConfigModel.$metaData
        }),
    };
})(TaxConfigModel || (TaxConfigModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var TaxCreatedModel;
(function (TaxCreatedModel) {
    TaxCreatedModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(TaxCreatedModel || (TaxCreatedModel = {}));

var TaxItemModel;
(function (TaxItemModel) {
    TaxItemModel.ServiceTypeEnumValues = Object.freeze(['Other', 'Accommodation', 'FoodAndBeverages']);
})(TaxItemModel || (TaxItemModel = {}));
(function (TaxItemModel) {
    TaxItemModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        serviceType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: TaxItemModel.ServiceTypeEnumValues,
            isPrimitiveType: true,
        }),
        isSubjectToTax: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        subAccountId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        appliedTo: Object.freeze({
            type: 'Array<TaxConfigModel>',
            isListContainer: true,
        }),
        ignoredFor: Object.freeze({
            type: 'Array<TaxConfigModel>',
            isListContainer: true,
        }),
        taxPeriods: Object.freeze({
            isRequired: true,
            type: 'Array<TaxPeriodModel>',
            isListContainer: true,
        }),
    };
})(TaxItemModel || (TaxItemModel = {}));

var TaxListModel;
(function (TaxListModel) {
    TaxListModel.$metaData = {
        taxes: Object.freeze({
            isRequired: true,
            type: 'Array<TaxItemModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(TaxListModel || (TaxListModel = {}));

var TaxModel;
(function (TaxModel) {
    TaxModel.ServiceTypeEnumValues = Object.freeze(['Other', 'Accommodation', 'FoodAndBeverages']);
})(TaxModel || (TaxModel = {}));
(function (TaxModel) {
    TaxModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        code: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            type: '{ [key: string]: string; }',
            isPrimitiveType: true,
            isMapContainer: true,
        }),
        propertyId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        serviceType: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: TaxModel.ServiceTypeEnumValues,
            isPrimitiveType: true,
        }),
        isSubjectToTax: Object.freeze({
            type: 'boolean',
            isPrimitiveType: true,
        }),
        subAccountId: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        appliedTo: Object.freeze({
            type: 'Array<TaxConfigModel>',
            isListContainer: true,
        }),
        ignoredFor: Object.freeze({
            type: 'Array<TaxConfigModel>',
            isListContainer: true,
        }),
        taxPeriods: Object.freeze({
            isRequired: true,
            type: 'Array<TaxPeriodModel>',
            isListContainer: true,
        }),
    };
})(TaxModel || (TaxModel = {}));

/**
 * apaleo Settings API - not safe for work
 * Continuously evolving version - use at your own risk! Set up and change global account and property settings.
 *
 * OpenAPI spec version: v0-nsfw
 *
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var TaxPeriodModel;
(function (TaxPeriodModel) {
    TaxPeriodModel.$metaData = {
        percent: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
        validFrom: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
    };
})(TaxPeriodModel || (TaxPeriodModel = {}));

var TimeSliceDefinitionListModel;
(function (TimeSliceDefinitionListModel) {
    TimeSliceDefinitionListModel.$metaData = {
        timeSliceDefinitions: Object.freeze({
            isRequired: true,
            type: 'Array<TimeSliceDefinitionModel>',
            isListContainer: true,
        }),
        count: Object.freeze({
            isRequired: true,
            type: 'number',
            isPrimitiveType: true,
        }),
    };
})(TimeSliceDefinitionListModel || (TimeSliceDefinitionListModel = {}));

var TimeSliceDefinitionModel;
(function (TimeSliceDefinitionModel) {
    TimeSliceDefinitionModel.TemplateEnumValues = Object.freeze(['DayUse', 'OverNight']);
})(TimeSliceDefinitionModel || (TimeSliceDefinitionModel = {}));
(function (TimeSliceDefinitionModel) {
    TimeSliceDefinitionModel.$metaData = {
        id: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        name: Object.freeze({
            isRequired: true,
            minLength: 1,
            type: 'string',
            isPrimitiveType: true,
        }),
        template: Object.freeze({
            isRequired: true,
            type: 'string',
            isEnum: true,
            allowedEnumValues: TimeSliceDefinitionModel.TemplateEnumValues,
            isPrimitiveType: true,
        }),
        checkInTime: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        checkOutTime: Object.freeze({
            isRequired: true,
            type: 'string',
            isPrimitiveType: true,
        }),
        isUsed: Object.freeze({
            isRequired: true,
            type: 'boolean',
            isPrimitiveType: true,
        }),
        actions: Object.freeze({
            type: 'Array<ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason>',
            isListContainer: true,
        }),
    };
})(TimeSliceDefinitionModel || (TimeSliceDefinitionModel = {}));

class ApiModule {
    static forRoot(configurationFactory) {
        return {
            ngModule: ApiModule,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    }
    constructor(parentModule, http) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
        }
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
    static { this.ɵfac = function ApiModule_Factory(__ngFactoryType__) { return new (__ngFactoryType__ || ApiModule)(i0.ɵɵinject(ApiModule, 12), i0.ɵɵinject(i1.HttpClient, 8)); }; }
    static { this.ɵmod = /*@__PURE__*/ i0.ɵɵdefineNgModule({ type: ApiModule }); }
    static { this.ɵinj = /*@__PURE__*/ i0.ɵɵdefineInjector({ providers: [
            CapturePoliciesService,
            CityTaxService,
            CustomFeeService,
            CustomSubAccountsService,
            FeatureSettingsService,
            InvoiceAddressService,
            InvoiceLineItemGroupingService,
            LanguagesService,
            MarketSegmentService,
            PropertySettingsService,
            TaxService,
            TimeSliceDefinitionsService
        ] }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ApiModule, [{
        type: NgModule,
        args: [{
                imports: [],
                declarations: [],
                exports: [],
                providers: [
                    CapturePoliciesService,
                    CityTaxService,
                    CustomFeeService,
                    CustomSubAccountsService,
                    FeatureSettingsService,
                    InvoiceAddressService,
                    InvoiceLineItemGroupingService,
                    LanguagesService,
                    MarketSegmentService,
                    PropertySettingsService,
                    TaxService,
                    TimeSliceDefinitionsService
                ]
            }]
    }], () => [{ type: ApiModule, decorators: [{
                type: Optional
            }, {
                type: SkipSelf
            }] }, { type: i1.HttpClient, decorators: [{
                type: Optional
            }] }], null); })();

/**
 * Generated bundle index. Do not edit.
 */

export { APIS, ActionModelTimeSliceDefinitionActionNotAllowedTimeSliceDefinitionActionReason, ActionReasonModelNotAllowedTimeSliceDefinitionActionReason, ApiModule, BASE_PATH, COLLECTION_FORMATS, CapturePoliciesService, CapturePolicyItemModel, CapturePolicyListModel, CapturePolicyModel, CityTaxConfigModel, CityTaxCreatedModel, CityTaxItemModel, CityTaxListModel, CityTaxModel, CityTaxPricingRuleModel, CityTaxService, CityTaxSubcategoryAgeModel, CityTaxSubcategoryModel, Configuration, CountModel, CreateCityTaxModel, CreateCustomFeeModel, CreateCustomSubAccountModel, CreateMarketSegmentModel, CreateTaxModel, CreateTimeSliceDefinitionModel, CustomFeeCreatedModel, CustomFeeItemModel, CustomFeeListModel, CustomFeeModel, CustomFeeService, CustomSubAccountCreatedModel, CustomSubAccountModel, CustomSubAccountsListModel, CustomSubAccountsService, DistributionChannelTaxConfigModel, FeatureSettingsModel, FeatureSettingsService, InvoiceAddressCreateOrReplaceModel, InvoiceAddressListModel, InvoiceAddressModel, InvoiceAddressService, InvoiceLineItemGroupingModel, InvoiceLineItemGroupingService, LanguageModel, LanguagesModel, LanguagesService, MarketSegmentCreatedModel, MarketSegmentListModel, MarketSegmentModel, MarketSegmentService, MessageItemCollection, Operation, PropertySettingsModel, PropertySettingsService, ReplaceLanguageModel, ReplaceLanguagesModel, TaxConfigModel, TaxCreatedModel, TaxItemModel, TaxListModel, TaxModel, TaxPeriodModel, TaxService, TimeSliceDefinitionListModel, TimeSliceDefinitionModel, TimeSliceDefinitionsService, settingsPropertiesByPropertyIdTimeSliceDefinitionsByIdGet, settingsPropertiesByPropertyIdTimeSliceDefinitionsGet };
//# sourceMappingURL=apaleo-angular-api-proxy-settings.mjs.map
